pub enum Scope {
Global {
objs: Vec<Weak<DSO>>,
},
Local {
owner: Option<Weak<DSO>>,
objs: Vec<Arc<DSO>>,
},
}Variants
Global
The global scope initially contains the main program and all of its
dependencies. Additional objects will be added to this scope via
dlopen(2) if the RTLD_GLOBAL flag is set.
Local